@@ -45,6 +45,7 @@ from torch.nn.functional import adaptive_avg_pool2d
 
 from torchelper.metrics.measure import Metric
 from torchelper.archs.inception import InceptionV3
+from torchelper.utils import logger
 
 # try:
 #     from tqdm import tqdm
@@ -494,7 +495,7 @@ class FID(Metric):
             if not np.isfinite(covmean).all():
                 msg = ('fid calculation produces singular product; '
                     'adding %s to diagonal of cov estimates') % eps
-                print(msg)
+                logger.warn(msg)
                 offset = np.eye(sigma1.shape[0]) * eps
                 covmean = linalg.sqrtm((sigma1 + offset).dot(sigma2 + offset))
 
